# Accessibility

As a group, answer the following questions:

1. For each Principle of Universal Design, write 2-5 sentences or point form notes explaining which features your program adhere to that principle. If you do not have any such features you can either:

### Principle 1: Equitable Use

- All data is stored locally, and thus cannot be accessed outside the device. This means that the user's data cannot be distributed without their consent and can only be accessed by them and only them. This addresses all security concerns.
- Our app is open source and free, and thus everyone can have access to our app free of segregation and stigmatizing.
- Our app works with Android's built in screen reader TalkBack and text-to speech to support a diverse group of people. 
- One thing we could implement in the future is support for multiple languages. Right now our app is hard-coded in English. However, we could extract the strings into their own resource files and provide support for other languages by having a resource file for each language with the translated strings.

### Principle 2: Flexibility in Use

- Our app can be used by both left handed and right handed people.
- They can input strings with their own keyboard (regardless or language)
- One feature we could implement in the future is a landscape mode. This would provide different methods of choice for the user. We haven't implemented it right now to prevent the UI from breaking but this could definitely be a feature in the future

### Principle 3: Simple and Intuitive to Use

- Our app is very simple to use. The app just consists of tapping on event boxes or using the nav bar to navigate, or filling in forms to create a new event. Anything that requires user action is labeled or has a symbol that denotes the purpose or both.
- Our app uses very basic vocabulary, nothing that includes super difficult language.
- Important text is emphasised with the bold font, or font size, or even font color.
- Users from all different skill levels should be able to use our app with ease.

### Principle 4: Perceptible Information

- We have a calendar which allows the user to navigate information in a more visual way. The built-in text to speech for android can be easily used with our app as well.
- The different colors found throughout the app are chosen to contrast and not blend in with each other, this way words and other elements become much more readable.
- adquate sized font was used to maximize readability

### Principle 5: Tolorance for Error

- When deleting a person a delete confirmation message appears to notify the user of what they are about to do, and to make sure that the user is attentive of the important task at hand.
- The delete event button is in red, which is a common color to alert the user of danger. This will keep the user vigilante when they are deleting an event.

### Principle 6: Low Physical Effort

- In our app, we allow the user to create a person, and reuse that person, to prevent the tedious repetition of creating the same person over and over again.
- The app can be used however the user wants to use it, in any position they would like to use it.
- The only element that is restricting is the lack of landscape mode, which is defintely a feature that we should implement in the future to allow the user for more control over how they can use the app.

### Principle 7: Size and Space for Appraoch and Use

- The elements of our app are visible from all different angles due to the strong color contast between elements.
- We provide adequate sized buttons and widgets for the user to use, which can accomadate all sorts of hand sizes and grips.
- The TalkBack screen reader can be easily used with our app.


2. Write a paragraph about who you would market your program towards, if you were to sell or license your program to customers. This could be a specific category such as "students" or more vague, such as "people who like games". Try to give a bit more detail along with the category.

3. Write a paragraph about whether or not your program is less likely to be used by certain demographics. For example, a program that converts txt files to files that can be printed by a braille printer are less likely to be used by people who do not read braille.
